==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QPaintDeviceWindow_shell.h <==
#ifndef QPAINTDEVICEWINDOW_SHELL_H
#define QPAINTDEVICEWINDOW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qpaintdevicewindow.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qicon.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtGui/qwindow.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


class QPaintDeviceWindow_shell : public QPaintDeviceWindow, public QtJambiShellInterface
{
public:
    ~QPaintDeviceWindow_shell() override;

    QAccessibleInterface* accessibleRoot() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void exposeEvent(QExposeEvent* arg__1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    QObject* focusObject() const override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    QSurfaceFormat format() const override;
    void hideEvent(QHideEvent* arg__1) override;
    void initPainter(QPainter* painter0) const override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* arg__1) override;
    int metric(QPaintDevice::PaintDeviceMetric metric0) const override;
    void mouseDoubleClickEvent(QMouseEvent* arg__1) override;
    void mouseMoveEvent(QMouseEvent* arg__1) override;
    void mousePressEvent(QMouseEvent* arg__1) override;
    void mouseReleaseEvent(QMouseEvent* arg__1) override;
    void moveEvent(QMoveEvent* arg__1) override;
    void paintEvent(QPaintEvent* event0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* arg__1) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* arg__1) override;
    QSize size() const override;
    QSurface::SurfaceType surfaceType() const override;
    void tabletEvent(QTabletEvent* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* arg__1) override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPaintDeviceWindow_access : public QPaintDeviceWindow
{
    void __qt_exposeEvent_QExposeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_initPainter_QPainter_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0) const;
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint metric0) const;
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0) const;
    jobject __qt_sharedPainter_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPAINTDEVICEWINDOW_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QPaintDeviceWindow_shell.h <==
#ifndef QPAINTDEVICEWINDOW_SHELL_H
#define QPAINTDEVICEWINDOW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qpaintdevicewindow.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qicon.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtGui/qwindow.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


class QPaintDeviceWindow_shell : public QPaintDeviceWindow, public QtJambiShellInterface
{
public:
    ~QPaintDeviceWindow_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QPaintDeviceWindow_mshell;
    friend class QPaintDeviceWindow_oshell;
};


class QPaintDeviceWindow_mshell : public QPaintDeviceWindow_shell
{
public:
    using QPaintDeviceWindow_shell::QPaintDeviceWindow_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QPaintDeviceWindow_oshell : public QPaintDeviceWindow_mshell
{
public:
    using QPaintDeviceWindow_mshell::QPaintDeviceWindow_mshell;
    ~QPaintDeviceWindow_oshell() override;
    QAccessibleInterface* accessibleRoot() const override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* arg__1) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void exposeEvent(QExposeEvent* arg__1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    QObject* focusObject() const override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    QSurfaceFormat format() const override;
    void hideEvent(QHideEvent* arg__1) override;
    void initPainter(QPainter* painter0) const override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* arg__1) override;
    int metric(QPaintDevice::PaintDeviceMetric metric0) const override;
    void mouseDoubleClickEvent(QMouseEvent* arg__1) override;
    void mouseMoveEvent(QMouseEvent* arg__1) override;
    void mousePressEvent(QMouseEvent* arg__1) override;
    void mouseReleaseEvent(QMouseEvent* arg__1) override;
    void moveEvent(QMoveEvent* arg__1) override;
    void paintEvent(QPaintEvent* event0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* arg__1) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* arg__1) override;
    QSize size() const override;
    QSurface::SurfaceType surfaceType() const override;
    void tabletEvent(QTabletEvent* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* arg__1) override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPaintDeviceWindow_access : public QPaintDeviceWindow
{
    void __qt_exposeEvent_QExposeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_initPainter_QPainter_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0) const;
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint metric0) const;
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0) const;
    jobject __qt_sharedPainter_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPAINTDEVICEWINDOW_SHELL_H
